@@ -1,5 +1,7 @@
 import ast
 import pandas as pd
+from datetime import datetime
+from .configs import CHAIN_OPTIONS
 import swifter  # don't remove, is used as pd.Dataframe.swifter.apply(...)
 
 
@@ -23,7 +25,24 @@ def json_col_to_df(df, col_name, prefix=True, chunk_size=int(1e5)):
 
     my_list = []
     for start in range(0, len(df), chunk_size):
-        end = min(start+chunk_size, len(df))
+        end = min(start + chunk_size, len(df))
         my_list.append(_json_col_to_df(df.iloc[start:end, :], col_name))
 
     return pd.concat(my_list, axis=0)
+
+
+def validate_dateformat(date_text, format):
+    try:
+        datetime.strptime(date_text, format)
+    except ValueError:
+        return False
+    return True
+
+
+def valid_chain(chain):
+    if chain not in CHAIN_OPTIONS:
+        raise Exception(f"Chain: {chain} not supported. Currently support {CHAIN_OPTIONS}")
+
+
+def transfer_date_format(date_text, pre_format, post_format):
+    return datetime.strptime(date_text, pre_format).strftime(post_format)
